@@ -3,7 +3,7 @@
 #include <string.h>
 #include "vbe.h"
 /************* This is derived from ddcxinfo written by *****************\
-#ident "$Id: ddcxinfo-mol.c,v 1.1 2006/01/07 16:03:52 dgel Exp $"
+#ident "$Id: ddcxinfo-mol.c,v 1.2 2006/08/28 07:20:59 dgel Exp $"
 modified by Klaus Knopper <knoppix@knopper.net> for KNOPPIX Feb. 2003
 modified to max out the monitor for KNOPPIX July 2003
 \************************************************************************/
@@ -70,7 +70,8 @@ const char *default_modelines=
 "	# 1280x1024 @ 75Hz (VESA) hsync: 80.0kHz\n"
 "	ModeLine \"1280x1024\" 135.0 1280 1296 1440 1688   1024 1025 1028 1066 +hsync +vsync\n"
 "	# 1280x1024 @ 85Hz (VESA) hsync: 91.1kHz\n"
-"	ModeLine \"1280x1024\" 157.5 1280 1344 1504 1728   1024 1025 1028 1072 +hsync +vsync\n"
+"	# ModeLine \"1280x1024\" 157.5 1280 1344 1504 1728   1024 1025 1028 1072 +hsync +vsync\n"
+"	Modeline \"1280x1024\" 157.50 1280 1328 1488 1728  1024 1025 1028 1072 +hsync +vsync\n"
 "	# 1600x1200 @ 60Hz (VESA) hsync: 75.0kHz\n"
 "	ModeLine \"1600x1200\" 162.0 1600 1664 1856 2160   1200 1201 1204 1250 +hsync +vsync\n"
 "	# 1600x1200 @ 65Hz (VESA) hsync: 81.3kHz\n"
